Index: chrome/browser/resources/options2/content_settings_exceptions_area.js |
diff --git a/chrome/browser/resources/options2/content_settings_exceptions_area.js b/chrome/browser/resources/options2/content_settings_exceptions_area.js |
index ef4fa6bbd4b818de2408f6e2bf152dbfa9f77471..243ac4b85fe719a4091eebc695e10626440e8916 100644 |
--- a/chrome/browser/resources/options2/content_settings_exceptions_area.js |
+++ b/chrome/browser/resources/options2/content_settings_exceptions_area.js |
@@ -111,9 +111,10 @@ cr.define('options.contentSettings', function() { |
this.updateEditables(); |
// Editing notifications and geolocation is disabled for now. |
if (this.contentType == 'notifications' || |
- this.contentType == 'location') { |
+ this.contentType == 'location' || |
+ this.contentType == 'mediastream') { |
this.editable = false; |
} |
@@ -441,10 +442,11 @@ cr.define('options.contentSettings', function() { |
* Returns whether the rows are editable in this list. |
*/ |
isEditable: function() { |
// Editing notifications and geolocation is disabled for now. |
return !(this.contentType == 'notifications' || |
this.contentType == 'location' || |
- this.contentType == 'fullscreen'); |
+ this.contentType == 'fullscreen' || |
+ this.contentType == 'mediastream'); |
}, |
/** |
@@ -111,9 +111,10 @@ cr.define('options.contentSettings', function() { |
this.updateEditables(); |
- // Editing notifications and geolocation is disabled for now. |
+ // Editing notifications, geolocation and mediastream is disabled for now. |
if (this.contentType == 'notifications' || |
@@ -441,10 +442,11 @@ cr.define('options.contentSettings', function() { |
*/ |
isEditable: function() { |
- // Editing notifications and geolocation is disabled for now. |
+ // Editing notifications, geolocation and mediastream is disabled for now. |
return !(this.contentType == 'notifications' || |
this.contentType == 'location' || |